<?php
add_action( 'admin_init', 'lense_plugin_cpt_page_add_metaboxes' );
add_action( 'save_post', 'lense_plugin_cpt_page_update_meta' );

if ( ! function_exists( 'lense_plugin_cpt_page_add_metaboxes' ) ) :
	function lense_plugin_cpt_page_add_metaboxes() {
		add_meta_box( 'lense-plugin-title', esc_html__( 'Title', 'lense-plugin' ), 'lense_plugin_add_page_title_meta_box', 'page', 'normal', 'high' );
		add_meta_box( 'lense-plugin-tpl-gallery-page', esc_html__( 'Gallery Options', 'lense-plugin' ), 'lense_plugin_add_page_gallery_meta_box', 'page', 'normal', 'high' );
	}
endif;

if ( ! function_exists( 'lense_plugin_cpt_page_update_meta' ) ) :
	function lense_plugin_cpt_page_update_meta( $post_id ) {

		if ( ! lense_plugin_can_save_meta( 'page' ) ) {
			return;
		}

		update_post_meta( $post_id, 'lense_gallery_style', lense_plugin_sanitize_gallery_style( $_POST['lense_gallery_style'] ) );
		update_post_meta( $post_id, 'lense_gallery_loading_effect', lense_plugin_sanitize_loading_effect( $_POST['lense_gallery_loading_effect'] ) );
		update_post_meta( $post_id, 'lense_gallery_spacing', lense_plugin_sanitize_gallery_spacing( $_POST['lense_gallery_spacing'] ) );
		update_post_meta( $post_id, 'lense_gallery_gutter_size', lense_plugin_sanitize_intval_or_empty( $_POST['lense_gallery_gutter_size'] ) );
		lense_plugin_metabox_gallery_save( $_POST );

		update_post_meta( $post_id, 'page_title_hide', isset( $_POST['page_title_hide'] ) ? 1 : 0 );
	}
endif;

if ( ! function_exists( 'lense_plugin_add_page_gallery_meta_box' ) ) :
	function lense_plugin_add_page_gallery_meta_box( $object, $box ) {
		lense_plugin_prepare_metabox( 'page' );

		?><div class="ci-cf-wrap"><?php

			lense_plugin_metabox_open_tab( '' );
				lense_plugin_metabox_dropdown( 'lense_gallery_style', lense_plugin_get_gallery_style_choices(), esc_html__( 'Gallery Style', 'lense-plugin' ), array( 'default' => apply_filters( 'lense_sanitize_gallery_style_default', 'scroller' ) ) );

				lense_plugin_metabox_guide( esc_html__( 'The following options only apply to "Masonry" gallery styles.', 'lense-plugin' ) );
				lense_plugin_metabox_dropdown( 'lense_gallery_spacing', lense_plugin_get_gallery_spacing_choices(), esc_html__( 'Spacing:', 'lense-plugin' ) );
				lense_plugin_metabox_input( 'lense_gallery_gutter_size', esc_html__( 'Gutter size (leave empty for default):', 'lense-plugin' ), array( 'input_type' => 'number' ) );
				lense_plugin_metabox_dropdown( 'lense_gallery_loading_effect', lense_plugin_get_loading_effect_choices(), esc_html__( 'Loading effect:', 'lense-plugin' ) );

				lense_plugin_metabox_guide( wp_kses( __( 'You can create a gallery by pressing the <em>Add Images</em> button below.', 'lense-plugin' ), lense_plugin_get_allowed_tags( 'guide' ) ) );
				lense_plugin_metabox_gallery();

			lense_plugin_metabox_close_tab();

		?></div><?php

		lense_plugin_bind_metabox_to_page_template( 'lense-plugin-tpl-gallery-page', 'templates/gallery-page.php', 'lense_gallery_page_metabox_tpl' );
	}
endif;

if ( ! function_exists( 'lense_plugin_add_page_title_meta_box' ) ) :
	function lense_plugin_add_page_title_meta_box( $object, $box ) {
		lense_plugin_prepare_metabox( 'page' );

		?><div class="ci-cf-wrap"><?php

			lense_plugin_metabox_open_tab( '' );

				lense_plugin_metabox_checkbox( 'page_title_hide', 1, esc_html__( 'Hide page title.', 'lense-plugin' ) );

			lense_plugin_metabox_close_tab();

		?></div><?php
	}
endif;
