<?php
/*
Plugin Name: Lense theme-specific plugin
Description: Features required by the Lense theme.
Plugin URI: https://www.cssigniter.com/ignite/themes/lense/
Version: 1.0.1
License: GNU General Public License v2 or later
Author: The CSSIgniter Team
Author URI: https://www.cssigniter.com/
License: GNU General Public License v2 or later
License URI: http://www.gnu.org/licenses/gpl-2.0.html
Text Domain: lense-plugin
*/

if ( ! defined( 'LENSE_PLUGIN_VERSION' ) ) {
	define( 'LENSE_PLUGIN_VERSION', '1.0.1' );
}

if ( ! defined( 'LENSE_PLUGIN_DIR' ) ) {
	define( 'LENSE_PLUGIN_DIR', plugin_dir_path( __FILE__ ) );
}

if ( ! defined( 'LENSE_PLUGIN_DIR_URL' ) ) {
	define( 'LENSE_PLUGIN_DIR_URL', plugin_dir_url( __FILE__ ) );
}

add_action( 'after_setup_theme', 'lense_plugin_setup' );
function lense_plugin_setup() {
	load_plugin_textdomain( 'lense-plugin', false, dirname( plugin_basename( __FILE__ ) ) . '/languages' );
}

/**
 * Enqueue admin scripts and styles.
 */
function lense_plugin_admin_scripts( $hook ) {

	if ( ! wp_script_is( 'alpha-color-picker', 'enqueued' ) && ! wp_script_is( 'alpha-color-picker', 'registered' ) ) {
		wp_register_style( 'alpha-color-picker', untrailingslashit( LENSE_PLUGIN_DIR_URL ) . '/base/assets/vendor/alpha-color-picker/alpha-color-picker.css', array(
			'wp-color-picker',
		), '1.0.0' );
		wp_register_script( 'alpha-color-picker', untrailingslashit( LENSE_PLUGIN_DIR_URL ) . '/base/assets/vendor/alpha-color-picker/alpha-color-picker.js', array(
			'jquery',
			'wp-color-picker',
		), '1.0.0', true );
	}

	wp_register_style( 'lense-plugin-post-meta', untrailingslashit( LENSE_PLUGIN_DIR_URL ) . '/base/assets/css/post-meta.css', array(
		'alpha-color-picker',
	), LENSE_PLUGIN_VERSION );
	wp_register_script( 'lense-plugin-post-meta', untrailingslashit( LENSE_PLUGIN_DIR_URL ) . '/base/assets/js/post-meta.js', array(
		'media-editor',
		'jquery',
		'jquery-ui-sortable',
		'alpha-color-picker',
	), LENSE_PLUGIN_VERSION, true );

	$settings = array(
		'ajaxurl'             => admin_url( 'admin-ajax.php' ),
		'tSelectFile'         => esc_html__( 'Select file', 'lense-plugin' ),
		'tSelectFiles'        => esc_html__( 'Select files', 'lense-plugin' ),
		'tUseThisFile'        => esc_html__( 'Use this file', 'lense-plugin' ),
		'tUseTheseFiles'      => esc_html__( 'Use these files', 'lense-plugin' ),
		'tUpdateGallery'      => esc_html__( 'Update gallery', 'lense-plugin' ),
		'tLoading'            => esc_html__( 'Loading...', 'lense-plugin' ),
		'tPreviewUnavailable' => esc_html__( 'Gallery preview not available.', 'lense-plugin' ),
		'tRemoveImage'        => esc_html__( 'Remove image', 'lense-plugin' ),
		'tRemoveFromGallery'  => esc_html__( 'Remove from gallery', 'lense-plugin' ),
	);
	wp_localize_script( 'lense-plugin-post-meta', 'lense_plugin_PostMeta', $settings );


	//
	// Enqueue
	//
	if ( in_array( $hook, array( 'post.php', 'post-new.php' ), true ) ) {
		wp_enqueue_media();
		wp_enqueue_style( 'lense-plugin-post-meta' );
		wp_enqueue_script( 'lense-plugin-post-meta' );
	}

}
add_action( 'admin_enqueue_scripts', 'lense_plugin_admin_scripts' );


function lense_plugin_get_columns_classes( $columns ) {
	if ( function_exists( 'lense_get_columns_classes' ) ) {
		return lense_get_columns_classes( $columns );
	}

	switch ( intval( $columns ) ) {
		case 1:
			$classes = 'col-12';
			break;
		case 2:
			$classes = 'col-lg-6 col-12';
			break;
		case 3:
			$classes = 'col-xl-4 col-lg-6 col-12';
			break;
		case 4:
		default:
			$classes = 'col-xl-3 col-lg-6 col-12';
			break;
	}

	// Filter name intentionally same to lense_get_columns_classes()
	return apply_filters( 'lense_get_columns_classes', $classes, $columns );
}


function lense_plugin_get_gallery_style_choices() {
	return apply_filters( 'lense_plugin_gallery_style_choices', array(
		'scroller'  => esc_html__( 'Scroller', 'lense-plugin' ),
		'slider'    => esc_html__( 'Slider', 'lense-plugin' ),
		'justified' => esc_html__( 'Justified', 'lense-plugin' ),
		'masonry-2' => esc_html__( 'Masonry - 2 columns', 'lense-plugin' ),
		'masonry-3' => esc_html__( 'Masonry - 3 columns', 'lense-plugin' ),
		'masonry-4' => esc_html__( 'Masonry - 4 columns', 'lense-plugin' ),
	) );
}

function lense_plugin_sanitize_gallery_style( $value ) {
	$choices = lense_plugin_get_gallery_style_choices();
	if ( array_key_exists( $value, $choices ) ) {
		return $value;
	}

	return apply_filters( 'lense_sanitize_gallery_style_default', 'scroller' );
}

function lense_plugin_get_gallery_spacing_choices() {
	return apply_filters( 'lense_plugin_gallery_spacing_choices', array(
		''           => esc_html__( 'With gutters', 'lense-plugin' ),
		'no-gutters' => esc_html__( 'No gutters', 'lense-plugin' ),
	) );
}

function lense_plugin_sanitize_gallery_spacing( $value ) {
	$choices = lense_plugin_get_gallery_spacing_choices();
	if ( array_key_exists( $value, $choices ) ) {
		return $value;
	}

	return apply_filters( 'lense_plugin_sanitize_gallery_spacing_default', '' );
}



function lense_plugin_activated() {
	if ( ! current_user_can( 'activate_plugins' ) ) {
		return;
	}

	flush_rewrite_rules();
}
register_activation_hook( __FILE__, 'lense_plugin_activated' );

function lense_plugin_deactivated() {
	if ( ! current_user_can( 'activate_plugins' ) ) {
		return;
	}

	flush_rewrite_rules();
}
register_deactivation_hook( __FILE__, 'lense_plugin_deactivated' );



/**
 * Custom fields / post types / taxonomies.
 */
require untrailingslashit( LENSE_PLUGIN_DIR ) . '/custom-fields-page.php';

/**
 * Standard helper functions.
 */
require untrailingslashit( LENSE_PLUGIN_DIR ) . '/base/helpers.php';

/**
 * Standard sanitization functions.
 */
require untrailingslashit( LENSE_PLUGIN_DIR ) . '/base/sanitization.php';

/**
 * Post meta helpers.
 */
require untrailingslashit( LENSE_PLUGIN_DIR ) . '/base/post-meta.php';

/**
 * User fields.
 */
require untrailingslashit( LENSE_PLUGIN_DIR ) . '/user-meta.php';

/**
 * Theme-specific shortcodes.
 */
require untrailingslashit( LENSE_PLUGIN_DIR ) . '/shortcodes.php';
