<?php
/**
 * Lense functions and definitions
 */

if ( ! defined( 'LENSE_NAME' ) ) {
	define( 'LENSE_NAME', 'lense' );
}
if ( ! defined( 'LENSE_WHITELABEL' ) ) {
	// Set the following to true, if you want to remove any user-facing CSSIgniter traces.
	define( 'LENSE_WHITELABEL', false );
}

if ( ! function_exists( 'lense_setup' ) ) :
/**
 * Sets up theme defaults and registers support for various WordPress features.
 *
 * Note that this function is hooked into the after_setup_theme hook, which
 * runs before the init hook. The init hook is too late for some features, such
 * as indicating support for post thumbnails.
 */
function lense_setup() {

	// Default content width.
	$GLOBALS['content_width'] = 1000;

	// Remove filter-based base theme features not applicable in this theme.
	add_filter( 'lense_customizable_header', '__return_false' );
	add_filter( 'lense_customizable_footer', '__return_false' );
	add_filter( 'lense_customizable_blog_archive_options', '__return_false' );
	add_filter( 'lense_base_support_menu_2', '__return_false' );

	// Add common theme supports.
	lense_base_setup();

	// Image sizes
	set_post_thumbnail_size( 1000, 500, true );
	add_image_size( 'lense_narrow_width', 750, 500, true );
	add_image_size( 'lense_gallery_slide', 1355, 700, true );
	add_image_size( 'lense_gallery_scroller', 555, 700, true );
	add_image_size( 'lense_gallery_masonry', 665 );

	add_theme_support( 'lense-hide-single-featured', apply_filters( 'lense_theme_support_hide_single_featured_post_types', array(
		'post',
		'page',
	) ) );

	remove_action( 'widgets_init', 'lense_base_register_sidebars' );

	remove_action( 'lense_the_post_header', 'lense_the_post_entry_title', 10 );
	add_action( 'lense_the_post_header', 'lense_the_post_entry_title_override', 10 );

	// This provides back-compat for author descriptions on WP < 4.9. Remove by WP 5.1.
	if ( ! has_filter( 'get_the_author_description', 'wpautop' ) ) {
		add_filter( 'get_the_author_description', 'wpautop' );
	}
}
endif;
add_action( 'after_setup_theme', 'lense_setup' );

/**
 * Set the content width in pixels, based on the theme's design and stylesheet.
 *
 * Priority 0 to make it available to lower priority callbacks.
 *
 * @global int $content_width
 */
function lense_content_width() {
	$content_width = $GLOBALS['content_width'];

	if ( is_page_template( 'templates/builder.php' )
		|| is_page_template( 'templates/gallery-page.php' )
	) {
		$content_width = 1115;
	} elseif ( is_page_template( 'templates/narrow-width-page.php' ) ) {
		$content_width = 750;
	}

	$GLOBALS['content_width'] = apply_filters( 'lense_content_width', $content_width );
}
add_action( 'template_redirect', 'lense_content_width', 0 );

/**
 * Register widget areas.
 */
function lense_widgets_init() {
	register_sidebar( array(
		'name'          => esc_html__( 'Blog', 'lense' ),
		'id'            => 'sidebar-1',
		'description'   => esc_html__( 'Widgets added here will appear on the blog section.', 'lense' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );

	register_sidebar( array(
		'name'          => esc_html__( 'Page', 'lense' ),
		'id'            => 'sidebar-2',
		'description'   => esc_html__( 'Widgets added here will appear on the static pages.', 'lense' ),
		'before_widget' => '<aside id="%1$s" class="widget %2$s">',
		'after_widget'  => '</aside>',
		'before_title'  => '<h3 class="widget-title">',
		'after_title'   => '</h3>',
	) );
}
add_action( 'widgets_init', 'lense_widgets_init' );


/**
 * Register Google Fonts
 */
function lense_fonts_url() {
	$fonts_url = '';
	$fonts     = array();
	$subsets   = 'latin,latin-ext';

	/* translators: If there are characters in your language that are not supported by Raleway, translate this to 'off'. Do not translate into your own language. */
	if ( 'off' !== _x( 'on', 'Raleway font: on or off', 'lense' ) ) {
		$fonts[] = 'Raleway:500,500i,600,600i';
	}

	if ( $fonts ) {
		$fonts_url = add_query_arg( array(
			'family' => urlencode( implode( '|', $fonts ) ),
			'subset' => urlencode( $subsets ),
		), 'https://fonts.googleapis.com/css' );
	}

	return $fonts_url;
}

/**
 * Enqueue scripts and styles.
 */
function lense_scripts() {
	$theme = wp_get_theme();

	wp_register_style( 'lense-google-font', lense_fonts_url(), array(), null );
	wp_register_style( 'lense-base', get_template_directory_uri() . '/css/base.css', array(), $theme->get( 'Version' ) );
	wp_register_style( 'mCustomScrollbar', get_template_directory_uri() . '/css/jquery.mCustomScrollbar.css', array(), '3.1.12' );
	wp_register_style( 'justified-gallery', get_template_directory_uri() . '/css/justifiedGallery.min.css', array(), '3.6.3' );

	wp_register_style( 'lense-dependencies', false, array(
		'lense-google-font',
		'lense-base',
		'lense-common',
		'font-awesome',
		'slick',
		'mCustomScrollbar',
		'justified-gallery',
	), $theme->get( 'Version' ) );

	if ( is_child_theme() ) {
		wp_enqueue_style( 'lense-style-parent', get_template_directory_uri() . '/style.css', array(
			'lense-dependencies',
		), $theme->get( 'Version' ) );
	}

	wp_enqueue_style( 'lense-style', get_stylesheet_uri(), array(
		'lense-dependencies',
	), $theme->get( 'Version' ) );

	wp_register_script( 'fitVids', get_template_directory_uri() . '/js/jquery.fitvids.js', array( 'jquery' ), '1.1', true );
	wp_register_script( 'isotope', get_template_directory_uri() . '/js/isotope.pkgd.min.js', array( 'jquery' ), '3.0.2', true );
	wp_register_script( 'sticky-kit', get_template_directory_uri() . '/js/jquery.sticky-kit.min.js', array( 'jquery' ), '1.1.3', true );
	wp_register_script( 'mCustomScrollbar', get_template_directory_uri() . '/js/jquery.mCustomScrollbar.concat.min.js', array( 'jquery' ), '3.1.12', true );
	wp_register_script( 'justified-gallery', get_template_directory_uri() . '/js/jquery.justifiedGallery.min.js', array( 'jquery' ), '3.6.3', true );


	/*
	 * Enqueue
	 */
	wp_enqueue_script( 'lense-front-scripts', get_template_directory_uri() . '/js/scripts.js', array(
		'jquery',
		'slick',
		'fitVids',
		'isotope',
		'sticky-kit',
		'anim-on-scroll',
		'mCustomScrollbar',
		'justified-gallery',
	), $theme->get( 'Version' ), true );

}
add_action( 'wp_enqueue_scripts', 'lense_scripts' );


add_filter( 'wp_page_menu', 'lense_wp_page_menu', 10, 2 );
function lense_wp_page_menu( $menu, $args ) {
	$menu = preg_replace( '#^<div .*?>#', '', $menu, 1 );
	$menu = preg_replace( '#</div>$#', '', $menu, 1 );
	$menu = preg_replace( '#^<ul>#', '<ul id="' . esc_attr( $args['menu_id'] ) . '" class="' . esc_attr( $args['menu_class'] ) . '">', $menu, 1 );
	return $menu;
}

if ( ! function_exists( 'lense_get_columns_classes' ) ) :
	function lense_get_columns_classes( $columns ) {
		switch ( intval( $columns ) ) {
			case 1:
				$classes = 'col-12';
				break;
			case 2:
				$classes = 'col-lg-6 col-12';
				break;
			case 3:
				$classes = 'col-xl-4 col-lg-6 col-12';
				break;
			case 4:
			default:
				$classes = 'col-xl-3 col-lg-6 col-12';
				break;
		}

		return apply_filters( 'lense_get_columns_classes', $classes, $columns );
	}
endif;

function lense_the_post_entry_title_override() {
	if ( is_singular() && get_the_ID() === get_queried_object_id() ) {
		$hide = get_post_meta( get_the_ID(), 'page_title_hide', true );

		if ( ! $hide ) {
			?>
			<h1 class="entry-title">
				<?php the_title(); ?>
			</h1>
			<?php
		}
	} else {
		?>
		<h1 class="entry-title">
			<a href="<?php the_permalink(); ?>"><?php the_title(); ?></a>
		</h1>
		<?php
	}
}

/**
 * Echoes the logo / site title / description, depending on customizer options.
 */
function lense_the_site_identity_override() {
	do_action( 'lense_before_site_identity' );

	?><div class="site-branding"><?php

	if ( get_theme_mod( 'show_site_description', 1 ) ) {
		$description = get_bloginfo( 'description', 'display' );
		if ( $description || is_customize_preview() ) {
			?><p class="site-tagline"><?php echo $description; /* WPCS: xss ok. */ ?></p><?php
		}
	}

	if ( has_custom_logo() && get_theme_mod( 'show_site_title', 1 ) ) {
		the_custom_logo();

		?><h1 class="site-logo"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1><?php
	} elseif ( has_custom_logo() ) {
		?><h1 class="site-logo"><?php the_custom_logo(); ?></h1><?php
	} elseif ( get_theme_mod( 'show_site_title', 1 ) ) {
		?><h1 class="site-logo"><a href="<?php echo esc_url( home_url( '/' ) ); ?>" rel="home"><?php bloginfo( 'name' ); ?></a></h1><?php
	}

	?></div><?php

	do_action( 'lense_after_site_identity' );
}


function lense_page_gallery( $post_id = false ) {
	if ( empty( $post_id ) ) {
		$post_id = get_the_ID();
	}

	if ( ! function_exists( 'lense_plugin_featgal_get_attachments' ) ) {
		return '';
	}

	$gallery = lense_plugin_featgal_get_attachments( $post_id );
	if ( ! $gallery->have_posts() ) {
		return;
	}

	$gallery_style = get_post_meta( $post_id, 'lense_gallery_style', true );
	switch ( $gallery_style ) {
		case 'masonry-2':
		case 'masonry-3':
		case 'masonry-4':
			$columns = intval( str_replace( 'masonry-', '', $gallery_style ) );
			$gutters = get_post_meta( $post_id, 'lense_gallery_spacing', true );
			$effect  = get_post_meta( $post_id, 'lense_gallery_loading_effect', true );
			lense_page_gallery_masonry( $gallery, $columns, $gutters, $effect );
			break;
		case 'justified':
			lense_page_gallery_justified( $gallery );
			break;
		case 'slider':
			lense_page_gallery_slider( $gallery );
			break;
		case 'scroller':
		default:
			lense_page_gallery_scroller( $gallery );
			break;
	}

}

function lense_page_gallery_masonry( WP_Query $gallery, $columns = 4, $gutters = '', $effect = '' ) {
	$col_class = '';
	switch ( $columns ) {
		case 2:
			$col_class = 'row-two-col';
			break;
		case 3:
			$col_class = 'row-three-col';
			break;
		case 4:
		default:
			$col_class = 'row-four-col';
			break;
	}

	$classes = array(
		$col_class,
		$gutters,
	);

	if ( $effect ) {
		$classes[] = 'row-effect';
		$classes[] = sprintf( 'row-effect-%s', $effect );
	}

	$classes = array_filter( $classes );

	?>
	<div class="gallery-main row-items row-isotope <?php echo esc_attr( implode( ' ', $classes ) ); ?>">
		<?php while ( $gallery->have_posts() ) : $gallery->the_post(); ?>
			<div class="row-item">
				<div class="item">
					<a href="<?php echo esc_attr( wp_get_attachment_image_url( get_the_ID(), 'large' ) ); ?>" class="lense-lightbox">
						<?php $details = wp_prepare_attachment_for_js( get_the_ID() ); ?>
						<img src="<?php echo esc_attr( wp_get_attachment_image_url( get_the_ID(), 'lense_gallery_masonry' ) ); ?>" alt="<?php echo esc_attr( $details['caption'] ); ?>">
					</a>
				</div>
			</div>
		<?php endwhile; ?>
		<?php wp_reset_postdata(); ?>
	</div>
	<?php
}

function lense_page_gallery_justified( WP_Query $gallery ) {
	?>
	<div
		class="gallery-main gallery-justified"
		data-row-height="260"
		data-margins="1"
		data-border="0"
		data-lastRow="nojustify"
	>
		<?php while ( $gallery->have_posts() ) : $gallery->the_post(); ?>
			<a href="<?php echo esc_attr( wp_get_attachment_image_url( get_the_ID(), 'large' ) ); ?>" class="lense-lightbox">
				<?php $details = wp_prepare_attachment_for_js( get_the_ID() ); ?>
				<img src="<?php echo esc_attr( wp_get_attachment_image_url( get_the_ID(), 'large' ) ); ?>" alt="<?php echo esc_attr( $details['caption'] ); ?>">
			</a>
		<?php endwhile; ?>
		<?php wp_reset_postdata(); ?>
	</div>
	<?php
}

function lense_page_gallery_slider( WP_Query $gallery ) {
	?>
	<div
		class="gallery-slideshow"
		data-navigation="dots"
		data-effect="fade"
		data-speed="3000"
		data-autoslide="true"
	>
		<?php while ( $gallery->have_posts() ) : $gallery->the_post(); ?>
			<div class="gallery-slider-item">
				<a href="<?php echo esc_attr( wp_get_attachment_image_url( get_the_ID(), 'large' ) ); ?>" class="lense-lightbox">
					<?php $details = wp_prepare_attachment_for_js( get_the_ID() ); ?>
					<img src="<?php echo esc_attr( wp_get_attachment_image_url( get_the_ID(), 'lense_gallery_slide' ) ); ?>" alt="<?php echo esc_attr( $details['caption'] ); ?>">
				</a>
			</div>
		<?php endwhile; ?>
		<?php wp_reset_postdata(); ?>
	</div>
	<?php
}

function lense_page_gallery_scroller( WP_Query $gallery ) {
	?>
	<div class="gallery-scroller-wrap">
		<div class="gallery-scroller">
			<?php while ( $gallery->have_posts() ) : $gallery->the_post(); ?>
				<div class="gallery-scroller-item">
					<a href="<?php echo esc_attr( wp_get_attachment_image_url( get_the_ID(), 'large' ) ); ?>" class="lense-lightbox">
						<?php $details = wp_prepare_attachment_for_js( get_the_ID() ); ?>
						<img src="<?php echo esc_attr( wp_get_attachment_image_url( get_the_ID(), 'lense_gallery_scroller' ) ); ?>" alt="<?php echo esc_attr( $details['caption'] ); ?>">
					</a>
				</div>
			<?php endwhile; ?>
			<?php wp_reset_postdata(); ?>
		</div>
	</div>
	<?php
}


function lense_customize_preview_page_gallery( $_this, $container_context ) {
	lense_page_gallery();
}

add_action( 'wp_enqueue_scripts', 'lense_enqueue_single_gallery_css' );
function lense_enqueue_single_gallery_css() {
	if ( ! is_singular() ) {
		return;
	}

	$gutter = lense_sanitize_intval_or_empty( get_post_meta( get_queried_object_id(), 'lense_gallery_gutter_size', true ) );

	if ( ! function_exists( 'lense_plugin_featgal_get_attachments' ) ) {
		return;
	}

	$gallery = lense_plugin_featgal_get_attachments( get_queried_object_id() );
	if ( '' === $gutter || ! $gallery->have_posts() ) {
		return;
	}

	$gutter_css = '
		%1$s .row-items {
			margin-left: -%2$dpx;
			margin-right: -%2$dpx;
		}
	
		%1$s .row-items .row-item {
			padding-left: %2$dpx;
			padding-right: %2$dpx;
		}
	
		%1$s .row-items .row-item .item {
			margin-bottom: %3$dpx;
		}
';

	$id         = '#entry-' . get_queried_object_id();
	$half       = ceil( $gutter / 2 );
	$gutter_css = sprintf( $gutter_css, $id, $half, $gutter );

	wp_add_inline_style( 'lense-style', $gutter_css );
}



if ( ! defined( 'LENSE_WHITELABEL' ) || false === (bool) LENSE_WHITELABEL ) {
	add_filter( 'pt-ocdi/import_files', 'lense_ocdi_import_files' );
	add_action( 'pt-ocdi/after_import', 'lense_ocdi_after_import_setup' );
}

function lense_ocdi_import_files( $files ) {
	if ( ! defined( 'LENSE_NAME' ) ) {
		return $files;
	}

	$demo_dir_url = untrailingslashit( apply_filters( 'lense_ocdi_demo_dir_url', 'https://www.cssigniter.com/sample_content/' . LENSE_NAME ) );

	// When having more that one predefined imports, set a preview image, preview URL, and categories for isotope-style filtering.
	$new_files = array(
		array(
			'import_file_name'           => esc_html__( 'Demo Import', 'lense' ),
			'import_file_url'            => $demo_dir_url . '/content.xml',
			'import_widget_file_url'     => $demo_dir_url . '/widgets.wie',
			'import_customizer_file_url' => $demo_dir_url . '/customizer.dat',
		),
	);

	return array_merge( $files, $new_files );
}

function lense_ocdi_after_import_setup() {
	// Set up nav menus.
	$main_menu = get_term_by( 'name', 'Main Menu', 'nav_menu' );

	set_theme_mod( 'nav_menu_locations', array(
		'menu-1' => $main_menu->term_id,
	) );

	// Set up home and blog pages.
	$front_page_id = get_page_by_title( 'Scroller Gallery' );
	$blog_page_id  = get_page_by_title( 'Blog' );

	update_option( 'show_on_front', 'page' );
	update_option( 'page_on_front', $front_page_id->ID );
	update_option( 'page_for_posts', $blog_page_id->ID );
}

add_action( 'tgmpa_register', 'lense_register_required_plugins' );
function lense_register_required_plugins() {
	$plugins = array(
		array(
			'name'               => 'Lense theme-specific plugin', // The plugin name.
			'version'            => '1.0', // E.g. 1.0.0. If set, the active plugin must be this version or higher. If the plugin version is higher than the plugin version installed, the user will be notified to update the plugin.
			'slug'               => 'lense-plugin', // The plugin slug (typically the folder name).
			'source'             => get_template_directory() . '/plugins/lense-plugin.zip', // The plugin source.
			'required'           => true, // If false, the plugin is only 'recommended' instead of required.
			'force_activation'   => false, // If true, plugin is activated upon theme activation and cannot be deactivated until theme switch.
			'force_deactivation' => false, // If true, plugin is deactivated upon theme switch, useful for theme-specific plugins.
			'external_url'       => '', // If set, overrides default API URL and points to an external URL.
			'is_callable'        => '', // If set, this callable will be be checked for availability to determine if a plugin is active.
		),
	);

	$config = array(
		'id'           => 'lense',              // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);

	tgmpa( $plugins, $config );
}

/**
 * Common theme features.
 */
require_once get_theme_file_path( '/common/common.php' );

/**
 * Base theme functions and definitions.
 */
require_once get_theme_file_path( '/base/functions.php' );

/**
 * Customizer additions.
 */
require_once get_template_directory() . '/inc/customizer.php';

/**
 * Customizer styles.
 */
require_once get_theme_file_path( '/inc/customizer-styles.php' );

/**
 * TGM_Plugin_Activation class.
 */
require_once get_template_directory() . '/base/class-tgm-plugin-activation.php';
