<?php
	if ( ! function_exists( 'lense_get_customizer_css' ) ) :
		/**
		 * Generates CSS based on per-theme customizer settings.
		 *
		 * @return string
		 */
		function lense_get_customizer_css() {
			ob_start();

			//
			// Global Colors
			//
			$site_accent_color = get_theme_mod( 'site_accent_color' );

			if ( ! empty( $site_accent_color ) ) {
				?>
				a,
				.entry-title a:hover,
				.social-icon:hover,
				.text-theme {
					color: <?php echo sanitize_hex_color( $site_accent_color ); ?>;
				}

				a:hover {
					color: <?php echo sanitize_hex_color( lense_color_luminance( $site_accent_color, .1 ) ); ?>;
				}

				a:focus {
					outline: 1px dotted <?php echo sanitize_hex_color( $site_accent_color ); ?>;
				}

				input:focus,
				textarea:focus,
				.gallery-slideshow .slick-dots .slick-active button {
					border-color: <?php echo sanitize_hex_color( $site_accent_color ); ?>
				}

				.gallery-slideshow .slick-dots .slick-active button,
				.mCSB_scrollTools.mCSB_scrollTools_horizontal .mCSB_dragger .mCSB_dragger_bar {
					background-color: <?php echo sanitize_hex_color( $site_accent_color ); ?>
				}
				<?php
			}

			$site_text_color = get_theme_mod( 'site_text_color' );

			if ( ! empty( $site_text_color ) ) {
				$site_text_color_dark = lense_color_luminance( $site_text_color, -0.3 );
				$site_text_color_light = lense_color_luminance( $site_text_color, 0.1 );
				?>
				body,
				blockquote cite,
				.instagram-pics li a,
				.navigation-main a,
				.navigation a,
				.navigation .page-numbers,
				.page-links .page-number,
				.widget_meta li a,
				.widget_pages li a,
				.widget_categories li a,
				.widget_archive li a,
				.widget_nav_menu li a,
				.entry-tags a,
				.tag-cloud-link,
				.entry-title a,
				.social-icon {
					color: <?php echo sanitize_hex_color( $site_text_color ); ?>;
				}

				.comment-metadata,
				.site-tagline,
				.entry-meta {
					color: <?php echo sanitize_hex_color( $site_text_color_light ); ?>;
				}

				.navigation a,
				.navigation .page-numbers,
				.page-links .page-number,
				.entry-tags a,
				.tag-cloud-link,
				.btn-transparent {
					border-color: <?php echo sanitize_hex_color( $site_text_color_dark ); ?>;
				}

				h1, h2, h3, h4, h5, h6,
				.comment-author .fn,
				.navigation a:hover,
				.navigation .current,
				.page-links .page-number:hover,
				.ci-contact-widget-item i,
				.widget_meta li a:hover,
				.widget_pages li a:hover,
				.widget_categories li a:hover,
				.widget_archive li a:hover,
				.widget_nav_menu li a:hover,
				.entry-tags a:hover,
				.tag-cloud-link:hover {
					color: <?php echo sanitize_hex_color( $site_text_color_dark ); ?>;
				}

				.navigation a:hover,
				.navigation .current,
				.page-links .page-number:hover,
				.entry-tags a:hover,
				.tag-cloud-link:hover {
					border-color: <?php echo sanitize_hex_color( $site_text_color_dark ); ?>;
				}
				<?php
			}

			$site_border_color = get_theme_mod( 'site_border_color' );

			if ( ! empty( $site_border_color ) ) {
				?>
				blockquote,
				.no-comments,
				.widget select,
				.ci-schedule-widget-table tr,
				.widget_recent_comments li,
				.widget_rss li,
				.widget_recent_entries li,
				select {
					border-color: <?php echo sanitize_hex_color( $site_border_color ); ?>;
				}
				<?php
			}

			//
			// Typography
			//

			$lowercase_widget_titles = get_theme_mod( 'lowercase_widget_titles' );

			if ( $lowercase_widget_titles === 1 ) {
				?>
				.widget-title {
					text-transform: none;
				}
				<?php
			}

			$lowercase_content_titles = get_theme_mod( 'lowercase_content_titles' );

			if ( $lowercase_content_titles === 1 ) {
				?>
				.entry-title,
				.entry-content h1,
				.entry-content h2,
				.entry-content h3,
				.entry-content h4,
				.entry-content h5,
				.entry-content h6 {
					text-transform: none;
				}
				<?php
			}

			$lowercase_all = get_theme_mod( 'lowercase_all' );

			if ( $lowercase_all === 1 ) {
				?>
				.entry-title,
				h1, h2, h3, h4, h5, h6,
				label,
				.navigation-main a,
				.entry-content th,
				.comment-metadata,
				.comment-reply-link,
				.site-logo,
				.site-tagline,
				.entry-meta,
				.widget_meta li a,
				.widget_pages li a,
				.widget_categories li a,
				.widget_archive li a,
				.widget_nav_menu li a,
				.widget_recent_entries .post-date {
					text-transform: none;
				}
				<?php
			}

			$css = ob_get_clean();
			return apply_filters( 'lense_customizer_css', $css );
		}
	endif;
