/**
 * Base Theme Customizer enhancements for a better user experience.
 *
 * Contains handlers to make Base Theme Customizer preview reload changes asynchronously.
 *
 * https://developer.wordpress.org/themes/customize-api/tools-for-improved-user-experience/#using-postmessage-for-improved-setting-previewing
 */

(function ($) {
	function createStyleSheet(settingName, styles) {
		var $styleElement;

		style = '<style class="' + settingName + '">';
		style += styles.reduce(function (rules, style) {
			rules += style.selectors + '{' + style.property + ':' + style.value + ';} ';
			return rules;
		}, '');
		style += '</style>';

		$styleElement = $('.' + settingName);

		if ($styleElement.length) {
			$styleElement.replaceWith(style);
		} else {
			$('head').append(style);
		}
	}

	//
	// Theme global colors
	//
	wp.customize('site_accent_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('site_accent_color', [
				{
					property: 'color',
					value: to,
					selectors: 'a, .entry-title a:hover, .social-icon:hover, .text-theme'
				}
			]);
		});
	});

	wp.customize('site_text_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('site_text_color', [
				{
					property: 'color',
					value: to,
					selectors: 'body, blockquote cite, .instagram-pics li a, .section-subtitle a,	.navigation a,.navigation .page-numbers,.page-links .page-number,.widget_meta li a,.widget_pages li a,.widget_categories li a,.widget_archive li a,.widget_nav_menu li a,.entry-tags a,.tag-cloud-link,.btn-tranparent'
				},
				{
					property: 'border-color',
					value: to,
					selectors: '.navigation a,.navigation .page-numbers,.page-links .page-number,.entry-tags a,.tag-cloud-link,.btn-transparent'
				},
				{
					property: 'color',
					value: to,
					selectors: 'h1, h2, h3, h4, h5, h6,.comment-author .fn,.entry-title a,.filter-active,.item-media-content,.navigation a,.navigation .page-numbers,.social-icon,.ci-contact-widget-item i,.widget_meta li a:hover,.widget_pages li a:hover,.widget_categories li a:hover,.widget_archive li a:hover,.widget_nav_menu li a:hover,.entry-tags a:hover,.tag-cloud-link:hover,.btn-transparent:hover'
				},
				{
					property: 'border-color',
					value: to,
					selectors: '.filter-active,.navigation a,.navigation .page-numbers,.entry-tags a:hover,.tag-cloud-link:hover,.btn-transparent:hover'
				}
			]);
		});
	});

	wp.customize('site_border_color', function (value) {
		value.bind(function (to) {
			createStyleSheet('site_border_color', [
				{
					property: 'border-color',
					value: to,
					selectors: 'blockquote,.no-comments,.widget select,.ci-schedule-widget-table tr,.widget_recent_comments li,.widget_rss li,.widget_recent_entries li,select'
				}
			]);
		});
	});

	//
	// Typography options
	//
	wp.customize('lowercase_widget_titles', function (value) {
		value.bind(function (to) {
			if (to) {
				$('.widget-title').css('text-transform', 'none');
			} else {
				$('.widget-title').css('text-transform', 'uppercase');
			}
		});
	});

	wp.customize('lowercase_content_titles', function (value) {
		var $els = $('.entry-title, .entry-content h1, .entry-content h2,' +
			'.entry-content h3, .entry-content h4, .entry-content h5, ' +
			'.entry-content h6');

		value.bind(function (to) {
			if (to) {
				$els.css('text-transform', 'none');
			} else {
				$els.css('text-transform', 'uppercase');
			}
		});
	});

	wp.customize('lowercase_all', function (value) {
		var $els = $('.entry-title,h1, h2, h3, h4, h5, h6,label,.navigation-main a,' +
			'.entry-content th,.comment-metadata,.comment-reply-link,.site-logo,' +
			'.site-tagline,.entry-meta,.widget_meta li a,.widget_pages li a,' +
			'.widget_categories li a,	.widget_archive li a,.widget_nav_menu li a,' +
			'.widget_recent_entries .post-date');

		value.bind(function (to) {
			if (to) {
				$els.css('text-transform', 'none');
			} else {
				$els.css('text-transform', 'uppercase');
			}
		});
	});

})(jQuery);
