jQuery(function ($) {
	'use strict';

	var $window = $(window);
	var $body = $('body');
	
	/* -----------------------------------------
	 Menu
	 ----------------------------------------- */
	$( '.navigation-main .menu-item-has-children > a' ).after( '<button class="dropdown-toggle"></button>' );

	$( '.navigation-main .current-menu-ancestor > button' ).addClass( 'toggle-on' );
	$( '.navigation-main .current-menu-ancestor > .sub-menu' ).addClass( 'toggled-on' );

	$( '.dropdown-toggle' ).click( function( e ) {
		var self = $( this );
		e.preventDefault();

		self.toggleClass( 'toggle-on' );
		self.next( '.children, .sub-menu' ).toggleClass( 'toggled-on' );
	} );

	$( '.mobile-toggle' ).click( function( e ) {
		e.preventDefault();
		var self = $( this );

		self.toggleClass( 'toggled' );
		$( '.sidebar-wrap' ).toggle();
	});

	/* -----------------------------------------
	 Responsive Videos with fitVids
	 ----------------------------------------- */
	$body.fitVids();

	/* -----------------------------------------
	 Grid Animations Init
	 ----------------------------------------- */
	var $itemEffectLists = $('.row-effect');

	if ($itemEffectLists.length && window.AnimOnScroll) {
		$itemEffectLists.each(function () {
			var el = $(this).get(0);

			new AnimOnScroll(el, {
				minDuration: 0.4,
				maxDuration: 0.7,
				viewportFactor: 0.2
			});
		});
	}

	/* -----------------------------------------
	 Justified Galleries
	 ----------------------------------------- */
	var $galleryJustified = $('.gallery-justified');
	$galleryJustified.each(function () {
		var $this = $(this);

		$this.justifiedGallery({
			rowHeight: $this.data('row-height'),
			margins: $this.data('margins'),
			border: $this.data('border'),
			lastRow: $this.data('last-row'),
		}).on('jg.complete', function() {
			$body.trigger('sticky_kit:recalc');
		});
	});

	$window.on('load', function () {
		/* -----------------------------------------
		 Sticky Layout
		 ----------------------------------------- */
		$('.main, .sidebar').stick_in_parent({
			parent: '.layout-wrap'
		});

		/* -----------------------------------------
		 Gallery Scroller
		 ----------------------------------------- */
		var width = 0;
		var $scroller = $('.gallery-scroller');
		var $scrollerWrap = $('.gallery-scroller-wrap');
		var $scrollItems = $scroller.find('.gallery-scroller-item img');

		$scrollItems.each(function () {
			width += $(this).width();
		});

		$scroller.width(width);

		$scrollerWrap.mCustomScrollbar({
			axis: 'x',
			scrollbarPosition: 'outside',
			autoDraggerLength: false,
			scrollInertia: 0,
			mouseWheel: {
				enable: false,
			},
			callbacks: {
				// This is required otherwise element.mcs.left does not update
				onScroll: function () {}
			},
		});

		/* -----------------------------------------
		 Custom drag scrolling
		 ----------------------------------------- */
		var mousedown = false;
		var curMouseX = 0;
		var curElScrollX = 0;

		$('.lense-lightbox').on('click', function (e) {
			e.preventDefault();
			return false;
		});

		$scroller.on('mousedown', function (event) {
			mousedown = true;
			$body.addClass('gallery-grabbing');
			curMouseX = event.clientX;
			curElScrollX = -$scrollerWrap.get(0).mcs.left;

			event.preventDefault();
			event.stopPropagation();
		});

		$body.on('mouseup', function () {
			mousedown = false;
			$body.removeClass('gallery-grabbing');
			$scrollerWrap.removeClass('gallery-dragging');
		});

		$scrollerWrap.on('mousemove', function (event) {
			if (!mousedown) {
				return false;
			}

			var amountToScroll = curMouseX - event.clientX;
			var scroll = curElScrollX + amountToScroll;

			// Disable pointer events and switch cursor since the user is
			// dragging
			if (Math.abs(amountToScroll) > 10) {
				$scrollerWrap.addClass('gallery-dragging');
			}

			if (scroll < 0 ) {
				return;
			}

			$scrollerWrap.mCustomScrollbar('scrollTo', [0, scroll]);
		});


		/* -----------------------------------------
		 Gallery slideshow
		 ----------------------------------------- */
		var $gallerySlideshow = $('.gallery-slideshow');
		var navigation = $gallerySlideshow.data('navigation');
		var effect = $gallerySlideshow.data('effect');
		var speed = $gallerySlideshow.data('slide-speed');
		var auto = $gallerySlideshow.data('autoslide');

		if ($gallerySlideshow.length) {
			$gallerySlideshow.slick({
				lazyLoad: 'ondemand',
				arrows: navigation === 'arrows',
				dots: navigation === 'dots',
				fade: effect === 'fade',
				autoplaySpeed: speed,
				autoplay: auto === true,
			});

			$gallerySlideshow.on('lazyLoaded', function () {
				$body.trigger('sticky_kit:recalc');
			});
		}

		/* -----------------------------------------
		 Isotope Filtering
		 ----------------------------------------- */
		var $grid = $('.row-isotope').isotope();
		var $filters = $('.item-filter');

		$filters.on('click', function (event) {
			var $this = $(this);
			var filterValue = $this.data('filter');
			$filters.removeClass('filter-active');
			$this.addClass('filter-active');

			// Remove all grid effects which might interfere
			// with isotope's animations
			$($grid).removeClass(function (index, className) {
				return (className.match(/(^|\s)row-effect*\S+/g) || []).join(' ');
			});

			$grid.isotope({ filter: filterValue });
			event.preventDefault();
		});
	});
});
